@@ -2,7 +2,7 @@ from investing_algorithm_framework.utils.version import get_version
 from investing_algorithm_framework.core.context import \
     AlgorithmContextInitializer, AlgorithmContext
 from investing_algorithm_framework.core.portfolio_managers import \
-    PortfolioManager, BinancePortfolioManager
+    PortfolioManager, BinancePortfolioManager, SQLLitePortfolioManager
 from investing_algorithm_framework.core.order_executors import OrderExecutor, \
     BinanceOrderExecutor
 from investing_algorithm_framework.core.market_services import \
@@ -11,12 +11,14 @@ from investing_algorithm_framework.core.models.data_provider import \
     TradingDataTypes, OrderBook, Ticker
 from investing_algorithm_framework.core.models import OrderSide, Order, \
     Position, TimeUnit, db, Portfolio, OrderType, OrderStatus
+from investing_algorithm_framework.core.exceptions import \
+    OperationalException, ImproperlyConfigured
 from investing_algorithm_framework.app import App
 from investing_algorithm_framework.globals import current_app
 from investing_algorithm_framework.configuration import Config
 from investing_algorithm_framework.views import *
 
-VERSION = (0, 13, 0, 'alpha', 0)
+VERSION = (0, 13, 1, 'alpha', 0)
 
 __all__ = [
     "App",
@@ -41,5 +43,8 @@ __all__ = [
     "OrderStatus",
     "TradingDataTypes",
     "Ticker",
-    "OrderBook"
+    "OrderBook",
+    "OperationalException",
+    "ImproperlyConfigured",
+    "SQLLitePortfolioManager"
 ]
