@@ -88,48 +88,38 @@ def setup_database(config_object):
 
 
 def setup_logging(log_level):
-
-    logging_config = {
-        'version': 1,
-        'disable_existing_loggers': True,
-        'formatters': {
-            'standard': {
-                'format': '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
-            },
-        },
-        'handlers': {
-            'console': {
-                'level': 'INFO',
-                'formatter': 'standard',
-                'class': 'logging.StreamHandler',
-                'stream': 'ext://sys.stdout',  # Default is stderr
-            },
-        },
-        'loggers': {
-            '': {  # root logger
-                'handlers': ['console'],
-                'level': log_level,
-                'propagate': False
-            },
-            'app': {
-                'handlers': ['console'],
-                'level': log_level,
-                'propagate': False
-            },
-            'investing-algorithm-framework': {
-                'handlers': ['console'],
-                'level': log_level,
-                'propagate': False
-            },
-            "apscheduler.executors.default": {
-                'handlers': ['console'],
-                'level': "ERROR",
-                'propagate': False
-            }
-        }
-    }
-
-    logging.config.dictConfig(logging_config)
+    pass
+    # logging_config = {
+    #     'version': 1,
+    #     'disable_existing_loggers': True,
+    #     'formatters': {
+    #         'standard': {
+    #             'format': '%(asctime)s [%(levelname)s] %(name)s: %(message)s'
+    #         },
+    #     },
+    #     'handlers': {
+    #         'console': {
+    #             'level': 'INFO',
+    #             'formatter': 'standard',
+    #             'class': 'logging.StreamHandler',
+    #             'stream': 'ext://sys.stdout',  # Default is stderr
+    #         },
+    #     },
+    #     'loggers': {
+    #         '': {  # root logger
+    #             'handlers': ['console'],
+    #             'level': "DEBUG",
+    #             'propagate': False
+    #         },
+    #         'app': {
+    #             'handlers': ['console'],
+    #             'level': "DEBUG",
+    #             'propagate': False
+    #         },
+    #     }
+    # }
+    #
+    # logging.config.dictConfig(logging_config)
 
 
 def register_error_handlers(app) -> None:
